==> atmosphere-rest-twitter-0.2-sources.jar: org/atmosphere/samples/twitter/UsersState.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 */

package org.atmosphere.samples.twitter;

import java.util.HashMap;
import java.util.Map;
import org.atmosphere.cpr.AtmosphereEvent;

/**
 *
 * @author paulsandoz
 */
public class UsersState {

    private Map<String, UserStateData> map = new HashMap<String, UserStateData>();

    public static class UserStateData {
        public final AtmosphereEvent ae;

        public UserStateData(AtmosphereEvent ae) {
            this.ae = ae;
        }
    }

    public synchronized UserStateData get(String name) {
        return map.get(name);
    }

    public synchronized UserStateData create(String user, AtmosphereEvent ae) {
        UserStateData usd = get(user);
        if (usd != null)
            return null;

        usd = new UserStateData(ae);
        map.put(user, usd);
        return usd;
    }

    public synchronized boolean remove(String user) {
        return map.remove(user) != null;
    }
}

==> atmosphere-rest-twitter-0.5-sources.jar: org/atmosphere/samples/twitter/UsersState.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 */

package org.atmosphere.samples.twitter;

import java.util.HashMap;
import java.util.Map;
import org.atmosphere.cpr.Broadcaster;

/**
 *
 * @author paulsandoz
 */
public class UsersState {

    private Map<String, UserStateData> map = new HashMap<String, UserStateData>();

    public static class UserStateData {
        public final TwitterBroadcaster bc;

        public UserStateData(TwitterBroadcaster bc) {
            this.bc = bc;
        }
    }

    public synchronized UserStateData get(String name) {
        return map.get(name);
    }

    public synchronized UserStateData create(String user, TwitterBroadcaster bc) {
        UserStateData usd = get(user);
        if (usd != null)
            return null;

        usd = new UserStateData(bc);
        map.put(user, usd);
        return usd;
    }

    public synchronized boolean remove(String user) {
        return map.remove(user) != null;
    }
}
